@@ -2,7 +2,9 @@
 from ._equivalencechecker import EquivalenceChecker
 
 # Equivalence checker classes - TODO: big cleanup before exposing more
-from ._wmethod import WmethodEquivalenceChecker
+from ._wmethod import \
+    WmethodEquivalenceChecker,\
+    SmartWmethodEquivalenceCheckerV4 as SmartWmethodEquivalenceChecker
 from ._bruteforce import BFEquivalenceChecker
 from ._randomwalk import RandomWalkEquivalenceChecker
 
