@@ -30,7 +30,9 @@ class WmethodEquivalenceChecker(EquivalenceChecker):
 
         print('Attempting to determine distinguishing set')
         W = get_distinguishing_set(fsm)
-        if len(W) < 1:
+
+        # We shouldn't forget to check without distinguishing sequence, or we may miss some differences in some cases
+        if tuple() not in W:
             W.add(tuple())
 
         print('distinguishing:', W)
@@ -45,24 +47,12 @@ class WmethodEquivalenceChecker(EquivalenceChecker):
 
 
         for i in order:
-            print(i, '/', depth)
             for x in product(X, repeat=i):
                 for p in P:
                     for w in W:
                         test_sequence = p + x + w
-                        #print(test_sequence)
                         equivalent, counterexample = self._are_equivalent(fsm, test_sequence)
-                        #print("Test sequence: ", test_sequence)
                         if not equivalent:
-                            print("COUNTEREXAMPLE:", counterexample)
-                            fsm.reset()
-                            hyp_output = fsm.process_input(test_sequence)
-                            self.sul.reset()
-                            sul_output = self.sul.process_input(test_sequence)
-                            print("SUL OUTPUT:", sul_output)
-                            print("HYP OUTPUT:", hyp_output)
-                            if sul_output == hyp_output:
-                                print('WTF?!')
                             return equivalent, counterexample
 
         return equivalent, None
@@ -149,7 +139,7 @@ class SmartWmethodEquivalenceChecker(EquivalenceChecker):
         print("Depth:", depth)
 
         print("[info] Calculating distinguishing set")
-        W = get_distinguishing_set(fsm, check=False)
+        W = get_distinguishing_set(fsm)
 
         P = get_state_cover_set(fsm)
         print("[info] Got state cover set")
@@ -460,7 +450,12 @@ class SmartWmethodEquivalenceCheckerV4(EquivalenceChecker):
         print("Depth:", depth)
 
         print("[info] Calculating distinguishing set")
-        W = get_distinguishing_set(fsm, check=False)
+        W = get_distinguishing_set(fsm)
+        print("Dset: ", W)
+
+        # We shouldn't forget to check without distinguishing sequence, or we may miss some differences in some cases
+        if tuple() not in W:
+            W.add(tuple())
 
         P = get_state_cover_set(fsm)
         print("[info] Got state cover set")
@@ -476,7 +471,13 @@ class SmartWmethodEquivalenceCheckerV4(EquivalenceChecker):
         counterexample = None
 
         for access_sequence in self.acc_seq_order(P):
-            print("[info] Trying access sequence:", access_sequence)
+            # Get state name reached by acc seq
+            fsm.reset()
+            fsm.process_input(access_sequence)
+            _acc_seq_state_name = fsm.state.name
+            fsm.reset()
+
+            print("[info] Trying access sequence:", access_sequence, "State:", _acc_seq_state_name)
             to_visit = deque()
             to_visit.extend(A)
 
